@@ -22,10 +22,10 @@
 #include "testexception.h"
 #include "exceptions.h"
 
-#include <qtest.h>
+#include <QTest>
 QTEST_MAIN(ExceptionTest)
 
-using namespace KCalCore;
+using namespace KCalendarCore;
 
 void ExceptionTest::testValidity()
 {
